pub struct BufferStats {
pub line_count: usize,
pub byte_count: usize,
}Fields
line_count: usizebyte_count: usizeTrait Implementations
Sourceimpl Clone for BufferStats
impl Clone for BufferStats
Sourcefn clone(&self) -> BufferStats
fn clone(&self) -> BufferStats
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BufferStats
impl Debug for BufferStats
Sourceimpl Default for BufferStats
impl Default for BufferStats
Sourcefn default() -> BufferStats
fn default() -> BufferStats
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for BufferStats
impl<'de> Deserialize<'de> for BufferStats
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BufferStats
impl JsonSchema for BufferStats
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BufferStats
impl PartialEq for BufferStats
Sourceimpl Serialize for BufferStats
impl Serialize for BufferStats
impl Eq for BufferStats
impl StructuralPartialEq for BufferStats