pub struct MacFuseCapability {
pub available: bool,
pub provider: Option<String>,
pub version: Option<String>,
}Fields
available: boolprovider: Option<String>version: Option<String>Trait Implementations
Sourceimpl Clone for MacFuseCapability
impl Clone for MacFuseCapability
Sourcefn clone(&self) -> MacFuseCapability
fn clone(&self) -> MacFuseCapability
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MacFuseCapability
impl Debug for MacFuseCapability
Sourceimpl Default for MacFuseCapability
impl Default for MacFuseCapability
Sourcefn default() -> MacFuseCapability
fn default() -> MacFuseCapability
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for MacFuseCapability
impl<'de> Deserialize<'de> for MacFuseCapability
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MacFuseCapability
impl JsonSchema for MacFuseCapability
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MacFuseCapability
impl PartialEq for MacFuseCapability
Sourceimpl Serialize for MacFuseCapability
impl Serialize for MacFuseCapability
impl Eq for MacFuseCapability
impl StructuralPartialEq for MacFuseCapability